@@ -1,18 +1,16 @@
 /*
- * @licence app begin@
  * SPDX license identifier: MPL-2.0
  *
  * Copyright (C) 2011-2015, BMW AG
  *
- * This file is part of GENIVI Project DLT - Diagnostic Log and Trace.
+ * This file is part of COVESA Project DLT - Diagnostic Log and Trace.
  *
  * This Source Code Form is subject to the terms of the
  * Mozilla Public License (MPL), v. 2.0.
  * If a copy of the MPL was not distributed with this file,
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * For further information see http://www.genivi.org/.
- * @licence end@
+ * For further information see http://www.covesa.org/.
  */
 
 /*!
@@ -23,12 +21,12 @@
 License MPL-2.0: Mozilla Public License version 2.0 http://mozilla.org/MPL/2.0/.
 
 \par More information
-can be found at http://projects.genivi.org/diagnostic-log-trace/ \n
+can be found at http://projects.covesa.org/diagnostic-log-trace/ \n
 
 \par About DLT
 DLT is a reusable open source software component for standardized logging and tracing in infotainment ECUs based on the AUTOSAR 4.0 standard.
 The goal of DLT is the consolidation of the existing variety of logging and tracing protocols on one format.
 
 
-\image html genivi_chrome_1_transparent.png
+\image html covesalogo.png
 */
