@@ -3,14 +3,14 @@
  *
  * Copyright (C) 2011-2015, BMW AG
  *
- * This file is part of GENIVI Project DLT - Diagnostic Log and Trace.
+ * This file is part of COVESA Project DLT - Diagnostic Log and Trace.
  *
  * This Source Code Form is subject to the terms of the
  * Mozilla Public License (MPL), v. 2.0.
  * If a copy of the MPL was not distributed with this file,
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 
 /*!
@@ -104,6 +104,9 @@ typedef struct {
     int jvalue;
     int kvalue;
     int bvalue;
+    int port;
+    int sendSerialHeaderFlag;
+    int resyncSerialHeaderFlag;
     char ecuid[4];
     DltFile file;
     DltFilter filter;
@@ -125,6 +128,8 @@ void usage()
     printf("Options:\n");
     printf("  -v            Verbose mode\n");
     printf("  -h            Usage\n");
+    printf("  -S            Send message with serial header (Default: Without serial header)\n");
+    printf("  -R            Enable resync serial header\n");
     printf("  -y            Serial device mode\n");
     printf("  -b baudrate   Serial device baudrate (Default: 115200)\n");
     printf("  -e ecuid      Set ECU ID (Default: RECV)\n");
@@ -159,6 +164,8 @@ void usage()
     printf("  -j              Get log info\n");
     printf("  -k              Get software version\n");
     printf("  -u              unix port\n");
+    printf("  -p port       Use the given port instead the default port\n");
+    printf("                Cannot be used with serial devices\n");
 }
 /**
  * Function for sending get log info ctrl msg and printing the response.
@@ -205,9 +212,9 @@ void dlt_process_get_log_info(void)
             dlt_print_id(apid, app.app_id);
 
             if (app.app_description != 0)
-                printf("APID:%4s %s\n", apid, app.app_description);
+                printf("APID:%4.4s %s\n", apid, app.app_description);
             else
-                printf("APID:%4s \n", apid);
+                printf("APID:%4.4s \n", apid);
 
             for (j = 0; j < app.count_context_ids; j++) {
                 con = app.context_id_info[j];
@@ -215,13 +222,13 @@ void dlt_process_get_log_info(void)
                 dlt_print_id(ctid, con.context_id);
 
                 if (con.context_description != 0)
-                    printf("CTID:%4s %2d %2d %s\n",
+                    printf("CTID:%4.4s %2d %2d %s\n",
                         ctid,
                         con.log_level,
                         con.trace_status,
                         con.context_description);
                 else
-                    printf("CTID:%4s %2d %2d\n",
+                    printf("CTID:%4.4s %2d %2d\n",
                         ctid,
                         con.log_level,
                         con.trace_status);
@@ -297,6 +304,7 @@ int main(int argc, char *argv[])
         .ivalue = -1,
         .oflag = -1,
         .gflag = -1,
+        .port = 3490
     };
 
     /* Fetch command line arguments */
@@ -305,7 +313,7 @@ int main(int argc, char *argv[])
     /* Default return value */
     ret = 0;
 
-    while ((c = getopt (argc, argv, "vhye:b:a:c:s:m:x:t:l:r:d:f:i:ogjku")) != -1)
+    while ((c = getopt (argc, argv, "vhSRye:b:a:c:s:m:x:t:l:r:d:f:i:ogjkup:")) != -1)
         switch (c) {
         case 'v':
         {
@@ -317,6 +325,16 @@ int main(int argc, char *argv[])
             usage();
             return -1;
         }
+        case 'S':
+        {
+            dltdata.sendSerialHeaderFlag = 1;
+            break;
+        }
+        case 'R':
+        {
+            dltdata.resyncSerialHeaderFlag = 1;
+            break;
+        }
         case 'y':
         {
             dltdata.yflag = DLT_CLIENT_MODE_SERIAL;
@@ -437,6 +455,11 @@ int main(int argc, char *argv[])
             dltdata.yflag = DLT_CLIENT_MODE_UNIX;
             break;
         }
+        case 'p':
+        {
+            dltdata.port = atoi(optarg);
+            break;
+        }
         case '?':
         {
             if ((optopt == 'o') || (optopt == 'f'))
@@ -471,21 +494,27 @@ int main(int argc, char *argv[])
     {
         g_dltclient.mode = DLT_CLIENT_MODE_UNIX;
         g_dltclient.socketPath = NULL;
-        dlt_parse_config_param("ControlSocketPath", &g_dltclient.socketPath);
+        if (dlt_parse_config_param("ControlSocketPath",
+                &g_dltclient.socketPath) == DLT_RETURN_ERROR) {
+            /* Failed to read from conf, copy default */
+            if (dlt_client_set_socket_path(&g_dltclient, DLT_DAEMON_DEFAULT_CTRL_SOCK_PATH) == -1) {
+                pr_error("set socket path didn't succeed\n");
+                return -1;
+            }
+        }
     }
     else {
         g_dltclient.mode = DLT_CLIENT_MODE_TCP;
     }
 
     if (g_dltclient.mode == DLT_CLIENT_MODE_TCP) {
+        g_dltclient.port = dltdata.port;
         for (index = optind; index < argc; index++)
             if (dlt_client_set_server_ip(&g_dltclient, argv[index]) == -1) {
                 pr_error("set server ip didn't succeed\n");
                 return -1;
             }
 
-
-
         if (g_dltclient.servIP == 0) {
             /* no hostname selected, show usage and terminate */
             fprintf(stderr, "ERROR: No hostname selected\n");
@@ -502,8 +531,6 @@ int main(int argc, char *argv[])
                 return -1;
             }
 
-
-
         if (g_dltclient.serialDevice == 0) {
             /* no serial device name selected, show usage and terminate */
             fprintf(stderr, "ERROR: No serial device name specified\n");
@@ -514,6 +541,10 @@ int main(int argc, char *argv[])
         dlt_client_setbaudrate(&g_dltclient, dltdata.bvalue);
     }
 
+    /* Update the send and resync serial header flags based on command line option */
+    g_dltclient.send_serial_header = dltdata.sendSerialHeaderFlag;
+    g_dltclient.resync_serial_header = dltdata.resyncSerialHeaderFlag;
+
     /* initialise structure to use DLT file */
     dlt_file_init(&(dltdata.file), dltdata.vflag);
 
