@@ -15,7 +15,7 @@
  * \author Christoph Lipka <clipka@jp.adit-jv.com> ADIT 2015
  *
  * \file: dlt_daemon_offline_logstorage.c
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 
 #include <stdio.h>
@@ -233,9 +233,14 @@ DLT_STATIC DltReturnValue dlt_logstorage_split_multi(char *key,
     else {
         strncpy(ecuid, tok, DLT_ID_SIZE);
         tok = strtok(NULL, ":");
-        strncpy(apid, tok, DLT_ID_SIZE);
+
+        if (tok != NULL)
+            strncpy(apid, tok, DLT_ID_SIZE);
+
         tok = strtok(NULL, ":");
-        strncpy(ctid, tok, DLT_ID_SIZE);
+
+        if (tok != NULL)
+            strncpy(ctid, tok, DLT_ID_SIZE);
     }
 
     return DLT_RETURN_OK;
