@@ -4,14 +4,14 @@
  * Copyright (C) 2015, Advanced Driver Information Technology
  * Copyright of Advanced Driver Information Technology, Bosch and Denso.
  *
- * This file is part of GENIVI Project DLT - Diagnostic Log and Trace.
+ * This file is part of COVESA Project DLT - Diagnostic Log and Trace.
  *
  * This Source Code Form is subject to the terms of the
  * Mozilla Public License (MPL), v. 2.0.
  * If a copy of the MPL was not distributed with this file,
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 
 /*!
@@ -56,6 +56,9 @@
 #ifndef DLT_DAEMON_UNIX_SOCKET_H
 #define DLT_DAEMON_UNIX_SOCKET_H
 
+#ifdef ANDROID
+DltReturnValue dlt_daemon_unix_android_get_socket(int *sock, const char *sock_path);
+#endif
 int dlt_daemon_unix_socket_open(int *sock, char *socket_path, int type, int mask);
 int dlt_daemon_unix_socket_close(int sock);
 
