@@ -5,14 +5,14 @@
  * This code is developed by Advanced Driver Information Technology.
  * Copyright of Advanced Driver Information Technology, Bosch and DENSO.
  *
- * This file is part of GENIVI Project DLT - Diagnostic Log and Trace.
+ * This file is part of COVESA Project DLT - Diagnostic Log and Trace.
  *
  * This Source Code Form is subject to the terms of the
  * Mozilla Public License (MPL), v. 2.0.
  * If a copy of the MPL was not distributed with this file,
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 
 /*!
@@ -313,7 +313,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_control_messages(DltGatewayConnectio
             return DLT_RETURN_ERROR;
         }
 
-        con->p_control_msgs->id = (uint32_t) strtol(token, NULL, 16);
+        con->p_control_msgs->id = strtol(token, NULL, 16);
         con->p_control_msgs->user_id = DLT_SERVICE_ID_PASSIVE_NODE_CONNECT;
         con->p_control_msgs->type = CONTROL_MESSAGE_ON_STARTUP;
         con->p_control_msgs->req = CONTROL_MESSAGE_NOT_REQUESTED;
@@ -384,7 +384,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_periodic_control_messages(
         p_token = strtok_r(token, ":", &p_rest);
 
         if ((p_token != NULL) && (strlen(p_token) != 0)) {
-            id = (uint32_t) strtol(p_token, NULL, 16);
+            id = strtol(p_token, NULL, 16);
 
             /* get back to head */
             con->p_control_msgs = head;
@@ -393,7 +393,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_periodic_control_messages(
             while (con->p_control_msgs != NULL) {
                 if (con->p_control_msgs->id == id) {
                     con->p_control_msgs->type = CONTROL_MESSAGE_BOTH;
-                    con->p_control_msgs->interval = (int) strtol(p_rest, NULL, 10);
+                    con->p_control_msgs->interval = strtol(p_rest, NULL, 10);
 
                     if (con->p_control_msgs->interval <= 0)
                         dlt_vlog(LOG_WARNING,
@@ -430,7 +430,7 @@ DLT_STATIC DltReturnValue dlt_gateway_check_periodic_control_messages(
                 con->p_control_msgs->user_id = DLT_SERVICE_ID_PASSIVE_NODE_CONNECT;
                 con->p_control_msgs->type = CONTROL_MESSAGE_PERIODIC;
                 con->p_control_msgs->req = CONTROL_MESSAGE_NOT_REQUESTED;
-                con->p_control_msgs->interval = (int) strtol(p_rest, NULL, 10);
+                con->p_control_msgs->interval = strtol(p_rest, NULL, 10);
 
                 if (con->p_control_msgs->interval <= 0)
                     dlt_vlog(LOG_WARNING,
@@ -669,6 +669,9 @@ int dlt_gateway_configure(DltGateway *gateway, char *config_file, int verbose)
 
     /* read configuration file */
     file = dlt_config_file_init(config_file);
+    if(file == NULL) {
+        return DLT_RETURN_ERROR;
+    }
 
     /* get number of entries and allocate memory to store information */
     ret = dlt_config_file_get_num_sections(file, &num_sections);
@@ -697,7 +700,7 @@ int dlt_gateway_configure(DltGateway *gateway, char *config_file, int verbose)
         gateway->num_connections = num_sections - 1;
     }
 
-    gateway->connections = calloc((size_t) gateway->num_connections,
+    gateway->connections = calloc(gateway->num_connections,
                                 sizeof(DltGatewayConnection));
 
     if (gateway->connections == NULL) {
@@ -791,6 +794,10 @@ int dlt_gateway_configure(DltGateway *gateway, char *config_file, int verbose)
                              configuration_entries[j].key, value);
             }
 
+            if (!tmp.ip_address) {
+                invalid = 1;
+            }
+
             if (invalid) {
                 dlt_vlog(LOG_ERR,
                          "%s configuration is invalid.\n"
@@ -1167,8 +1174,8 @@ DLT_STATIC DltReturnValue dlt_gateway_parse_get_log_info(DltDaemon *daemon,
             if (dlt_daemon_context_add(daemon,
                                        app.app_id,
                                        con.context_id,
-                                       (int8_t) con.log_level,
-                                       (int8_t) con.trace_status,
+                                       con.log_level,
+                                       con.trace_status,
                                        0,
                                        -1,
                                        con.context_description,
@@ -1254,7 +1261,7 @@ DLT_STATIC int dlt_gateway_control_service_logstorage(DltDaemon *daemon,
                                                       int verbose)
 {
     unsigned int connection_type = 0;
-    uint32_t i = 0;
+    int i = 0;
 
     if (daemon_local->flags.offlineLogstorageMaxDevices <= 0) {
         dlt_log(LOG_INFO,
@@ -1269,7 +1276,7 @@ DLT_STATIC int dlt_gateway_control_service_logstorage(DltDaemon *daemon,
             /* Check if log level of running application needs an update */
             dlt_daemon_logstorage_update_application_loglevel(daemon,
                                                               daemon_local,
-                                                              (int) i,
+                                                              i,
                                                               verbose);
     }
 
@@ -1285,6 +1292,7 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
     DltGateway *gateway = NULL;
     DltGatewayConnection *con = NULL;
     DltMessage msg = { 0 };
+    bool b_reset_receiver = false;
 
     if ((daemon == NULL) || (daemon_local == NULL) || (receiver == NULL)) {
         dlt_vlog(LOG_ERR, "%s: wrong parameter\n", __func__);
@@ -1301,13 +1309,11 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
     }
 
     for (i = 0; i < gateway->num_connections; i++)
-        if (gateway->connections[i].client.sock == receiver->fd) {
+        if ((gateway->connections[i].status == DLT_GATEWAY_CONNECTED) && (gateway->connections[i].client.sock == receiver->fd)) {
             con = &gateway->connections[i];
             break;
         }
 
-
-
     if (con == NULL) {
         dlt_log(LOG_ERR, "Cannot associate fd to passive Node connection\n");
         return DLT_RETURN_ERROR;
@@ -1349,7 +1355,7 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
 
     while (dlt_message_read(&msg,
                             (unsigned char *)receiver->buf,
-                            (unsigned int) receiver->bytesRcvd,
+                            receiver->bytesRcvd,
                             0,
                             verbose) == DLT_MESSAGE_ERROR_OK) {
         DltStandardHeaderExtra *header = (DltStandardHeaderExtra *)
@@ -1358,14 +1364,15 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
              sizeof(DltStandardHeader));
 
         /* only forward messages if the received ECUid is the expected one */
-        if (strncmp(header->ecu, con->ecuid, strlen(con->ecuid)) == 0) {
+        if (strncmp(header->ecu, con->ecuid, DLT_ID_SIZE) == 0) {
             uint32_t id;
             uint32_t id_tmp;
             DltPassiveControlMessage *control_msg = con->p_control_msgs;
 
             dlt_vlog(LOG_DEBUG,
-                     "Received ECUid (%s) similar to configured ECUid(%s). "
+                     "Received ECUid (%.*s) similar to configured ECUid(%s). "
                      "Forwarding message (%s).\n",
+                     DLT_ID_SIZE,
                      header->ecu,
                      con->ecuid,
                      msg.databuffer);
@@ -1422,14 +1429,15 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
                                        msg.headerbuffer,
                                        sizeof(DltStorageHeader),
                                        msg.headerbuffer + sizeof(DltStorageHeader),
-                                       (int) (msg.headersize - sizeof(DltStorageHeader)),
+                                       msg.headersize - sizeof(DltStorageHeader),
                                        msg.databuffer,
-                                       (int) msg.datasize,
+                                       msg.datasize,
                                        verbose);
         } else { /* otherwise remove this connection and do not connect again */
             dlt_vlog(LOG_WARNING,
-                     "Received ECUid (%s) differs to configured ECUid(%s). "
+                     "Received ECUid (%.*s) differs to configured ECUid(%s). "
                      "Discard this message.\n",
+                     DLT_ID_SIZE,
                      header->ecu,
                      con->ecuid);
 
@@ -1445,29 +1453,37 @@ DltReturnValue dlt_gateway_process_passive_node_messages(DltDaemon *daemon,
 
             dlt_log(LOG_WARNING,
                     "Disconnect from passive node due to invalid ECUid\n");
+
+            /* it is possible that a partial log was received through the last recv call */
+            /* however, the rest will never be received since the socket will be closed by above method */
+            /* as such, we need to reset the receiver to prevent permanent corruption */
+            b_reset_receiver = true;
         }
 
         if (msg.found_serialheader) {
             if (dlt_receiver_remove(receiver,
-                                    (int) (msg.headersize +
+                                    msg.headersize +
                                     msg.datasize -
                                     sizeof(DltStorageHeader) +
-                                    sizeof(dltSerialHeader))) == -1) {
+                                    sizeof(dltSerialHeader)) == -1) {
                 /* Return value ignored */
                 dlt_message_free(&msg, verbose);
                 return DLT_RETURN_ERROR;
             }
         }
         else if (dlt_receiver_remove(receiver,
-                                     (int) (msg.headersize +
+                                     msg.headersize +
                                      msg.datasize -
-                                     sizeof(DltStorageHeader))) == -1) {
+                                     sizeof(DltStorageHeader)) == -1) {
             /* Return value ignored */
             dlt_message_free(&msg, verbose);
             return DLT_RETURN_ERROR;
         }
     }
 
+    if (b_reset_receiver)
+        dlt_receiver_remove(receiver, receiver->bytesRcvd);
+
     if (dlt_receiver_move_to_begin(receiver) == -1) {
         /* Return value ignored */
         dlt_message_free(&msg, verbose);
@@ -1539,7 +1555,7 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
     for (i = 0; i < gateway->num_connections; i++)
         if (strncmp(gateway->connections[i].ecuid,
                     ecu,
-                    strlen(gateway->connections[i].ecuid)) == 0) {
+                    DLT_ID_SIZE) == 0) {
             con = &gateway->connections[i];
             break;
         }
@@ -1557,7 +1573,7 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
     }
 
     if (con->send_serial) { /* send serial header */
-        ret = (int) send(con->client.sock,
+        ret = send(con->client.sock,
                    (void *)dltSerialHeader,
                    sizeof(dltSerialHeader),
                    0);
@@ -1568,7 +1584,7 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
         }
     }
 
-    ret = (int) send(con->client.sock,
+    ret = send(con->client.sock,
                msg->headerbuffer + sizeof(DltStorageHeader),
                msg->headersize - sizeof(DltStorageHeader),
                0);
@@ -1578,7 +1594,7 @@ int dlt_gateway_forward_control_message(DltGateway *gateway,
         return DLT_RETURN_ERROR;
     }
     else {
-        ret = (int) send(con->client.sock, msg->databuffer, msg->datasize, 0);
+        ret = send(con->client.sock, msg->databuffer, msg->datasize, 0);
 
         if (ret == -1) {
             dlt_log(LOG_ERR, "Sending message to passive DLT Daemon failed\n");
@@ -1697,7 +1713,7 @@ int dlt_gateway_send_control_message(DltGatewayConnection *con,
     }
 
     if (con->send_serial) { /* send serial header */
-        ret = (int) send(con->client.sock,
+        ret = send(con->client.sock,
                    (void *)dltSerialHeader,
                    sizeof(dltSerialHeader),
                    0);
