@@ -15,13 +15,14 @@
  * \author Christoph Lipka <clipka@jp.adit-jv.com> ADIT 2015
  *
  * \file: dlt_offline_logstorage.c
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <ctype.h>
+#include <sys/syslog.h>
 #include <syslog.h>
 #include <sys/stat.h>
 #include <sys/stat.h>
@@ -73,6 +74,11 @@ DLT_STATIC void dlt_logstorage_filter_config_free(DltLogStorageFilterConfig *dat
     if (data->log != NULL)
         fclose(data->log);
 
+#ifdef DLT_LOGSTORAGE_USE_GZIP
+    if (data->gzlog != NULL)
+        gzclose(data->gzlog);
+#endif
+
     if (data->cache != NULL) {
         free(data->cache);
         data->cache = NULL;
@@ -193,7 +199,7 @@ DLT_STATIC int dlt_logstorage_list_add(char *keys,
         return -1;
 
     tmp->key_list = (char *)calloc(
-                (size_t) (num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN), sizeof(char));
+                (num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN), sizeof(char));
     if (tmp->key_list == NULL)
     {
         free(tmp);
@@ -201,7 +207,7 @@ DLT_STATIC int dlt_logstorage_list_add(char *keys,
         return -1;
     }
 
-    memcpy(tmp->key_list, keys, (size_t) (num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN));
+    memcpy(tmp->key_list, keys, num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN);
     tmp->num_keys = num_keys;
     tmp->next = NULL;
     tmp->data = calloc(1, sizeof(DltLogStorageFilterConfig));
@@ -326,8 +332,8 @@ void dlt_logstorage_free(DltLogStorage *handle, int reason)
 DLT_STATIC int dlt_logstorage_read_list_of_names(char **names, char *value)
 {
     int i = 0;
-    size_t y = 0;
-    size_t len = 0;
+    int y = 0;
+    int len = 0;
     char *tok;
     int num = 1;
 
@@ -349,7 +355,7 @@ DLT_STATIC int dlt_logstorage_read_list_of_names(char **names, char *value)
     num = dlt_logstorage_count_ids(value);
 
     /* need to alloc space for 5 chars, 4 for the name and "," and "\0" */
-    *names = (char *)calloc((size_t) (num * 5), sizeof(char));
+    *names = (char *)calloc(num * 5, sizeof(char));
 
     if (*names == NULL)
         return -1;
@@ -399,7 +405,7 @@ DLT_STATIC int dlt_logstorage_read_number(unsigned int *number, char *value)
         return -1;
 
     *number = 0;
-    len = (int) strlen(value);
+    len = strlen(value);
 
     /* check if string consists of digits only */
     for (i = 0; i < len; i++)
@@ -420,6 +426,34 @@ DLT_STATIC int dlt_logstorage_read_number(unsigned int *number, char *value)
     return 0;
 }
 
+/**
+ * dlt_logstorage_read_bool
+ *
+ * Evaluate a boolean config value. Values such as '1', 'on' or 'true' will be
+ * treated as true otherwise the config value will be interpreted as false.
+ *
+ * @param bool     The boolean to populate
+ * @param value    The string from the config file
+ * @returns        0 on success, -1 on error
+ */
+DLT_STATIC int dlt_logstorage_read_bool(unsigned int *boolean, char *value)
+{
+    int len = 0;
+    if (value == NULL)
+        return -1;
+
+    len = strnlen(value, 5);
+    *boolean = 0;
+    if (strncmp(value, "on", len) == 0) {
+        *boolean = 1;
+    } else if (strncmp(value, "true", len) == 0) {
+        *boolean = 1;
+    } else if (strncmp(value, "1", len) == 0) {
+        *boolean = 1;
+    }
+    return 0;
+}
+
 /**
  * dlt_logstorage_get_keys_list
  *
@@ -495,10 +529,10 @@ DLT_STATIC void dlt_logstorage_create_keys_only_ctid(char *ecuid, char *ctid,
                                                      char *key)
 {
     char curr_str[DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN + 1] = { 0 };
-    size_t curr_len = 0;
+    int curr_len = 0;
 
     if (ecuid != NULL) {
-        strncpy(curr_str, ecuid, strlen(ecuid));
+        strncpy(curr_str, ecuid, DLT_ID_SIZE);
         strncat(curr_str, "::", 2);
     }
     else {
@@ -527,10 +561,10 @@ DLT_STATIC void dlt_logstorage_create_keys_only_apid(char *ecuid, char *apid,
                                                      char *key)
 {
     char curr_str[DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN + 1] = { 0 };
-    size_t curr_len = 0;
+    int curr_len = 0;
 
     if (ecuid != NULL) {
-        strncpy(curr_str, ecuid, strlen(ecuid));
+        strncpy(curr_str, ecuid, DLT_ID_SIZE);
         strncat(curr_str, ":", 1);
     }
     else {
@@ -561,10 +595,10 @@ DLT_STATIC void dlt_logstorage_create_keys_multi(char *ecuid, char *apid,
                                                  char *ctid, char *key)
 {
     char curr_str[DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN + 1] = { 0 };
-    size_t curr_len = 0;
+    int curr_len = 0;
 
     if (ecuid != NULL) {
-        strncpy(curr_str, ecuid, strlen(ecuid));
+        strncpy(curr_str, ecuid, DLT_ID_SIZE);
         strncat(curr_str, ":", 1);
     }
     else {
@@ -595,7 +629,7 @@ DLT_STATIC void dlt_logstorage_create_keys_only_ecu(char *ecuid, char *key)
 {
     char curr_str[DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN + 1] = { 0 };
 
-    strncpy(curr_str, ecuid, strlen(ecuid));
+    strncpy(curr_str, ecuid, DLT_ID_SIZE);
     strncat(curr_str, "::", 2);
 
     strncpy(key, curr_str, strlen(curr_str));
@@ -651,7 +685,7 @@ DLT_STATIC int dlt_logstorage_create_keys(char *apids,
          (ctids != NULL) && (strncmp(ctids, ".*", 2) == 0) && (ecuid != NULL)) ) {
         dlt_logstorage_create_keys_only_ecu(ecuid, curr_key);
         *(num_keys) = 1;
-        *(keys) = (char *)calloc((size_t) (*num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN),
+        *(keys) = (char *)calloc(*num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN,
                                  sizeof(char));
 
         if (*(keys) == NULL)
@@ -682,7 +716,7 @@ DLT_STATIC int dlt_logstorage_create_keys(char *apids,
     *(num_keys) = num_apids * num_ctids;
 
     /* allocate memory for needed number of keys */
-    *(keys) = (char *)calloc((size_t) (*num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN),
+    *(keys) = (char *)calloc(*num_keys * DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN,
                              sizeof(char));
 
     if (*(keys) == NULL) {
@@ -822,20 +856,20 @@ DLT_STATIC int dlt_logstorage_validate_filter_name(char *name)
 {
     int len = 0;
     int idx = 0;
-    size_t config_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_CONFIG_SECTION);
-    size_t storage_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_STORAGE_SECTION);
-    size_t control_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_CONTROL_SECTION);
+    int config_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_CONFIG_SECTION);
+    int storage_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_STORAGE_SECTION);
+    int control_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_CONTROL_SECTION);
 
     if (name == NULL)
         return -1;
 
-    len = (int) strlen(name);
+    len = strlen(name);
 
     /* Check if section header is of format "FILTER" followed by a number */
     if (strncmp(name,
                 DLT_OFFLINE_LOGSTORAGE_CONFIG_SECTION,
                 config_sec_len) == 0) {
-        for (idx = (int) config_sec_len; idx < len - 1; idx++)
+        for (idx = config_sec_len; idx < len - 1; idx++)
             if (!isdigit(name[idx]))
                 return -1;
 
@@ -846,7 +880,7 @@ DLT_STATIC int dlt_logstorage_validate_filter_name(char *name)
                      DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_STORAGE_SECTION,
                      storage_sec_len) == 0)
     {
-        for (idx = (int) storage_sec_len; idx < len - 1; idx++)
+        for (idx = storage_sec_len; idx < len - 1; idx++)
             if (!isdigit(name[idx]))
                 return -1;
 
@@ -857,7 +891,7 @@ DLT_STATIC int dlt_logstorage_validate_filter_name(char *name)
                      DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_CONTROL_SECTION,
                      control_sec_len) == 0)
     {
-        for (idx = (int) control_sec_len; idx < len - 1; idx++)
+        for (idx = control_sec_len; idx < len - 1; idx++)
             if (!isdigit(name[idx]))
                 return -1;
 
@@ -1001,7 +1035,7 @@ DLT_STATIC int dlt_logstorage_check_reset_loglevel(DltLogStorageFilterConfig *co
 DLT_STATIC int dlt_logstorage_check_filename(DltLogStorageFilterConfig *config,
                                              char *value)
 {
-    size_t len;
+    int len;
 
     if ((value == NULL) || (strcmp(value, "") == 0))
         return -1;
@@ -1015,7 +1049,7 @@ DLT_STATIC int dlt_logstorage_check_filename(DltLogStorageFilterConfig *config,
 
     /* do not allow the user to change directory by adding a relative path */
     if (strstr(value, "..") == NULL) {
-        config->file_name = calloc(len + 1, sizeof(char));
+        config->file_name = calloc((len + 1), sizeof(char));
 
         if (config->file_name == NULL) {
             dlt_log(LOG_ERR,
@@ -1052,6 +1086,20 @@ DLT_STATIC int dlt_logstorage_check_nofiles(DltLogStorageFilterConfig *config,
     return dlt_logstorage_read_number(&config->num_files, value);
 }
 
+DLT_STATIC int dlt_logstorage_check_gzip_compression(DltLogStorageFilterConfig *config,
+                                                     char *value)
+{
+    if ((config == NULL) || (value == NULL))
+        return -1;
+
+    int result = dlt_logstorage_read_bool(&config->gzip_compression, value);
+#ifndef DLT_LOGSTORAGE_USE_GZIP
+    dlt_log(LOG_WARNING, "dlt-daemon not compiled with logstorage gzip support\n");
+    config->gzip_compression = 0;
+#endif
+    return result;
+}
+
 DLT_STATIC int dlt_logstorage_check_specificsize(DltLogStorageFilterConfig *config,
                                                  char *value)
 {
@@ -1123,7 +1171,7 @@ DLT_STATIC int dlt_logstorage_check_sync_strategy(DltLogStorageFilterConfig *con
 DLT_STATIC int dlt_logstorage_check_ecuid(DltLogStorageFilterConfig *config,
                                           char *value)
 {
-    size_t len;
+    int len;
 
     if ((config == NULL) || (value == NULL) || (value[0] == '\0'))
         return -1;
@@ -1134,7 +1182,7 @@ DLT_STATIC int dlt_logstorage_check_ecuid(DltLogStorageFilterConfig *config,
     }
 
     len = strlen(value);
-    config->ecuid = calloc(len + 1, sizeof(char));
+    config->ecuid = calloc((len + 1), sizeof(char));
 
     if (config->ecuid == NULL)
         return -1;
@@ -1195,6 +1243,11 @@ DLT_STATIC DltLogstorageFilterConf
         .key = "SpecificSize",
         .func = dlt_logstorage_check_specificsize,
         .is_opt = 1
+    },
+    [DLT_LOGSTORAGE_FILTER_CONF_GZIP_COMPRESSION] = {
+        .key = "GzipCompression",
+        .func = dlt_logstorage_check_gzip_compression,
+        .is_opt = 1
     }
 };
 
@@ -1250,6 +1303,11 @@ DLT_STATIC DltLogstorageFilterConf
         .key = NULL,
         .func = dlt_logstorage_check_specificsize,
         .is_opt = 1
+    },
+    [DLT_LOGSTORAGE_FILTER_CONF_GZIP_COMPRESSION] = {
+        .key = "GzipCompression",
+        .func = dlt_logstorage_check_gzip_compression,
+        .is_opt = 1
     }
 };
 
@@ -1304,6 +1362,11 @@ DLT_STATIC DltLogstorageFilterConf
         .key = NULL,
         .func = dlt_logstorage_check_specificsize,
         .is_opt = 1
+    },
+    [DLT_LOGSTORAGE_FILTER_CONF_GZIP_COMPRESSION] = {
+        .key = "GzipCompression",
+        .func = dlt_logstorage_check_gzip_compression,
+        .is_opt = 1
     }
 };
 /**
@@ -1368,9 +1431,9 @@ DLT_STATIC int dlt_logstorage_get_filter_value(DltConfigFile *config_file,
                                                char *value)
 {
     int ret = 0;
-    size_t config_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_CONFIG_SECTION);
-    size_t storage_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_STORAGE_SECTION);
-    size_t control_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_CONTROL_SECTION);
+    int config_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_CONFIG_SECTION);
+    int storage_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_STORAGE_SECTION);
+    int control_sec_len = strlen(DLT_OFFLINE_LOGSTORAGE_NONVERBOSE_CONTROL_SECTION);
 
     if ((config_file == NULL) || (sec_name == NULL))
         return DLT_OFFLINE_LOGSTORAGE_FILTER_ERROR;
@@ -1931,9 +1994,9 @@ int dlt_logstorage_get_config(DltLogStorage *handle,
     char key[DLT_CONFIG_FILE_SECTIONS_MAX][DLT_OFFLINE_LOGSTORAGE_MAX_KEY_LEN] =
     { { '\0' }, { '\0' }, { '\0' } };
     int i = 0;
-    size_t apid_len = 0;
-    size_t ctid_len = 0;
-    size_t ecuid_len = 0;
+    int apid_len = 0;
+    int ctid_len = 0;
+    int ecuid_len = 0;
     int num_configs = 0;
     int num = 0;
 
@@ -2161,10 +2224,10 @@ int dlt_logstorage_write(DltLogStorage *handle,
                                              + sizeof(DltStandardHeader));
 
     if (DLT_IS_HTYP_UEH(standardHeader->htyp)) {
-        header_len = (unsigned int) (sizeof(DltStandardHeader) + sizeof(DltExtendedHeader) + standardHeaderExtraLen);
+        header_len = sizeof(DltStandardHeader) + sizeof(DltExtendedHeader) + standardHeaderExtraLen;
 
         /* check if size2 is big enough to contain expected DLT message header */
-        if ((unsigned int) size2 < header_len) {
+        if ((unsigned int)size2 < header_len) {
             dlt_log(LOG_ERR, "DLT message header is too small\n");
             return 0;
         }
@@ -2185,10 +2248,10 @@ int dlt_logstorage_write(DltLogStorage *handle,
         }
     }
     else {
-        header_len = (unsigned int) (sizeof(DltStandardHeader) + standardHeaderExtraLen);
+        header_len = sizeof(DltStandardHeader) + standardHeaderExtraLen;
 
         /* check if size2 is big enough to contain expected DLT message header */
-        if ((unsigned int) size2 < header_len) {
+        if ((unsigned int)size2 < header_len) {
             dlt_log(LOG_ERR, "DLT message header is too small (without extended header)\n");
             return 0;
         }
