@@ -3,14 +3,14 @@
  *
  * Copyright (C) 2011-2015, BMW AG
  *
- * This file is part of GENIVI Project DLT - Diagnostic Log and Trace.
+ * This file is part of COVESA Project DLT - Diagnostic Log and Trace.
  *
  * This Source Code Form is subject to the terms of the
  * Mozilla Public License (MPL), v. 2.0.
  * If a copy of the MPL was not distributed with this file,
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 
 /*!
@@ -68,6 +68,7 @@
 #include <ctype.h>      /* for isprint() */
 #include <stdlib.h>     /* for atoi() */
 #include <string.h>     /* for strcmp() */
+#include <fcntl.h>
 #include <sys/uio.h>    /* for writev() */
 
 #include "dlt_client.h"
