@@ -5,14 +5,14 @@
  * This code is developed by Advanced Driver Information Technology.
  * Copyright of Advanced Driver Information Technology, Bosch and DENSO.
  *
- * This file is part of GENIVI Project DLT - Diagnostic Log and Trace.
+ * This file is part of COVESA Project DLT - Diagnostic Log and Trace.
  *
  * This Source Code Form is subject to the terms of the
  * Mozilla Public License (MPL), v. 2.0.
  * If a copy of the MPL was not distributed with this file,
  * You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * For further information see http://www.genivi.org/.
+ * For further information see http://www.covesa.org/.
  */
 
 /*!
@@ -146,8 +146,6 @@ TEST(t_dlt_gateway_send_control_message, Normal)
 TEST(t_dlt_gateway_send_control_message, nullpointer)
 {
     DltDaemonLocal daemon_local;
-    DltFilterConfiguration current;
-    daemon_local.pFilter.current = &current;
     DltGatewayConnection connections;
     DltConnection connections1;
     DltReceiver receiver1;
@@ -409,6 +407,8 @@ TEST(t_dlt_gateway_get_connection_receiver, normal)
     DltReceiver *ret = NULL;
     DltGateway gateway;
     DltGatewayConnection connections;
+    memset(&gateway, 0, sizeof(DltGateway));
+    memset(&connections, 0, sizeof(DltGatewayConnection));
     gateway.connections = &connections;
     int fd = 10;
     gateway.num_connections = 1;
@@ -425,6 +425,8 @@ TEST(t_dlt_gateway_get_connection_receiver, abnormal)
     DltReceiver *ret = NULL;
     DltGateway gateway;
     DltGatewayConnection connections;
+    memset(&gateway, 0, sizeof(DltGateway));
+    memset(&connections, 0, sizeof(DltGatewayConnection));
     gateway.connections = &connections;
     int fd = 10;
     gateway.num_connections = 1;
