@@ -6,14 +6,14 @@
 # This code is developed by Advanced Driver Information Technology.
 # Copyright of Advanced Driver Information Technology, Bosch and DENSO.
 #
-# This file is part of GENIVI Project DLT - Diagnostic Log and Trace.
+# This file is part of COVESA Project DLT - Diagnostic Log and Trace.
 #
 # This Source Code Form is subject to the terms of the
 # Mozilla Public License (MPL), v. 2.0.
 # If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# For further information see http://www.genivi.org/.
+# For further information see http://www.covesa.org/.
 ################################################################################
 
 ################################################################################
@@ -40,6 +40,21 @@ getOSname()
     OS="`uname`"
 }
 
+################################################################################
+# Function:    -getDltDaemonPath()
+#
+# Description  -Retrieves path to dlt-daemon
+#
+getDltDaemonPath()
+{
+    if [ -z "${DLT_UT_DAEMON_PATH}" ]; then
+        echo "WARNNG: env variable DLT_UT_DAEMON_PATH is not set"
+        DLT_DAEMON=`which dlt-daemon`
+    else
+        DLT_DAEMON="${DLT_UT_DAEMON_PATH}"
+    fi
+}
+
 ################################################################################
 #
 # Function:    -cleanup()
@@ -92,10 +107,11 @@ cleanup()
 
     cd $tmpPath
 
-    PIDOF dlt-daemon
+    BASE=`basename $DLT_DAEMON`
+    PIDOF $BASE
     if [ $? -eq '0' ]
     then
-        KILLALL dlt-daemon
+        KILLALL $BASE
         if [ $? -eq '1' ]
         then
             echo "Failed to kill daemons"
@@ -186,7 +202,7 @@ startDaemons()
 {
     DLT_PASSIVE_SHM_NAME=""
     tmpPath=/tmp
-    dlt-daemon -c $tmpPath/dlt_passive.conf &
+    dlt-daemon -d
     sleep 1
 
     # Check if the dlt shm file exist (DLT_SHM_ENABLE=ON)
@@ -194,7 +210,7 @@ startDaemons()
         DLT_PASSIVE_SHM_NAME="-s dlt-shm-passive"
     fi
 
-    dlt-daemon -p 3495 -c $tmpPath/dlt.conf $DLT_PASSIVE_SHM_NAME &
+    dlt-daemon -d -p 3495 -c $tmpPath/dlt.conf $DLT_PASSIVE_SHM_NAME
     return 0
 }
 
@@ -205,11 +221,12 @@ startDaemons()
 #
 checkDaemonStart()
 {
+    BASE=`basename $DLT_DAEMON`
     if [ "$OS" = "QNX" ]; then
-        slay -p dlt-daemon > /dev/null
+        slay -p $BASE > /dev/null
         total=$?
     else
-        total=`pgrep -c dlt-daemon`
+        total=`pgrep -c $BASE`
     fi
 
     if [ $total -ne '2' ]; then
@@ -234,6 +251,8 @@ executeTests()
 
 getOSname
 
+getDltDaemonPath
+
 echo "Cleaning up dlt-daemon instances"
 cleanup
 
